##  How to Model Organization Structured by Regions Only
For this example, looking at the application matrix report is helpful to see which applications are used for which business capabilities in the different regions. This will help you understand, e.g., rationalization potential if other regions use various applications for the same capabilities:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27561a4e7a44101487629b0ba6c4033c_LowRes.png)
